# Webhooks
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/webhooks#overview)
  * [Creating a Webhook](https://help.sap.com/docs/leanix/ea/webhooks#creating-a-webhook)
  * [Event Types and Payloads](https://help.sap.com/docs/leanix/ea/webhooks#event-types-and-payloads)
  * [PUSH Webhooks](https://help.sap.com/docs/leanix/ea/webhooks#push-webhooks)
  * [PULL Webhooks](https://help.sap.com/docs/leanix/ea/webhooks#pull-webhooks)


Listen to events in SAP LeanIX using webhooks.
